pub struct Mechanism(pub String);Expand description
A <mechanism/> element, describing one mechanism allowed by the server to authenticate.
Tuple Fields
0: StringTrait Implementations
Sourceimpl AsXml for Mechanism
impl AsXml for Mechanism
impl Eq for Mechanism
Sourceimpl FromXml for Mechanism
impl FromXml for Mechanism
Sourcetype Builder = MechanismFromXmlBuilder
type Builder = MechanismFromXmlBuilder
A builder type used to construct the element. Read more
Sourcefn from_events(
name: QName,
attrs: AttrMap,
ctx: &Context<'_>,
) -> Result<Self::Builder, FromEventsError>
fn from_events( name: QName, attrs: AttrMap, ctx: &Context<'_>, ) -> Result<Self::Builder, FromEventsError>
Attempt to initiate the streamed construction of this struct from XML. Read more
Sourcefn xml_name_matcher() -> XmlNameMatcher<'static>
fn xml_name_matcher() -> XmlNameMatcher<'static>
Return a predicate which determines if
Self may be parsed from
a given XML element. Read moreimpl StructuralPartialEq for Mechanism